@@ -1,4 +1,4 @@
-//! [`Archive`] implementation for hashmaps.
+//! [`Archive`](crate::Archive) implementation for hashmaps.
 //!
 //! During archiving, hashmaps are built into minimal perfect hashmaps using
 //! [compress, hash and displace](http://cmph.sourceforge.net/papers/esa09.pdf).
@@ -7,8 +7,11 @@
 pub mod validation;
 
 use crate::{
-    collections::hash_index::{ArchivedHashIndex, HashIndexResolver},
-    Archive, RelPtr,
+    collections::{
+        hash_index::{ArchivedHashIndex, HashIndexResolver},
+        util::Entry,
+    },
+    RelPtr,
 };
 #[cfg(feature = "alloc")]
 use crate::{
@@ -19,26 +22,6 @@ use core::{
     borrow::Borrow, fmt, hash::Hash, iter::FusedIterator, marker::PhantomData, ops::Index, pin::Pin,
 };
 
-#[cfg_attr(feature = "strict", repr(C))]
-struct Entry<K, V> {
-    key: K,
-    value: V,
-}
-
-impl<K: Archive, V: Archive> Archive for Entry<&'_ K, &'_ V> {
-    type Archived = Entry<K::Archived, V::Archived>;
-    type Resolver = (K::Resolver, V::Resolver);
-
-    #[inline]
-    unsafe fn resolve(&self, pos: usize, resolver: Self::Resolver, out: *mut Self::Archived) {
-        let (fp, fo) = out_field!(out.key);
-        self.key.resolve(pos + fp, resolver.0, fo);
-
-        let (fp, fo) = out_field!(out.value);
-        self.value.resolve(pos + fp, resolver.1, fo);
-    }
-}
-
 /// An archived `HashMap`.
 #[cfg_attr(feature = "strict", repr(C))]
 pub struct ArchivedHashMap<K, V> {
